==> jrdb-0.1.1-py3-none-any.whl: jrdb/schema/cyb.py <==
schema = {
    "name": "cyb",
    "type": "record",
    "fields": [
        {"start":   0, "end":   2, "type": "string", "name": "place_id"},
        {"start":   2, "end":   4, "type": "string", "name": "year"},
        {"start":   4, "end":   5, "type": "string", "name": "kai"},
        {"start":   5, "end":   6, "type": "string", "name": "nichi"},
        {"start":   6, "end":   8, "type": "string", "name": "number_of_race"},
        {"start":   8, "end":  10, "type": "string", "name": "pp"},
        {"start":  10, "end":  12, "type": "string", "name": "training_type_id"},
        {"start":  12, "end":  13, "type": "string", "name": "course_id"},
        {"start":  13, "end":  15, "type": "string", "name": "slope"},
        {"start":  15, "end":  17, "type": "string", "name": "wood"},
        {"start":  17, "end":  19, "type": "string", "name": "dirt"},
        {"start":  19, "end":  21, "type": "string", "name": "turf"},
        {"start":  21, "end":  23, "type": "string", "name": "pool"},
        {"start":  23, "end":  25, "type": "string", "name": "hurdle"},
        {"start":  25, "end":  27, "type": "string", "name": "poly"},
        {"start":  27, "end":  28, "type": "string", "name": "training_distance"},
        {"start":  28, "end":  29, "type": "string", "name": "training_point"},
        {"start":  29, "end":  32, "type": "string", "name": "workout_score"},
        {"start":  32, "end":  35, "type": "string", "name": "condition_score"},
        {"start":  35, "end":  36, "type": "string", "name": "training_value"},
        {"start":  36, "end":  37, "type": "string", "name": "condition_score_diff_id"},
        {"start":  37, "end":  77, "type": "string", "name": "training_comment"},
        {"start":  77, "end":  85, "type": "string", "name": "comment_yyyymmdd"},
        {"start":  85, "end":  86, "type": "string", "name": "training_evaluation"}
    ]
}

==> jrdb-0.2.0-py3-none-any.whl: jrdb/schema/cyb.py <==
schema = {
    "name": "cyb",
    "type": "record",
    "fields": [
        {"start":   0, "end":   2, "type": "string", "name": "place_id"},
        {"start":   2, "end":   4, "type": "string", "name": "year"},
        {"start":   4, "end":   5, "type": "string", "name": "kai"},
        {"start":   5, "end":   6, "type": "string", "name": "nichi"},
        {"start":   6, "end":   8, "type": "string", "name": "number_of_race"},
        {"start":   8, "end":  10, "type": "string", "name": "pp"},
        {"start":  10, "end":  12, "type": "string", "name": "training_type_id"},
        {"start":  12, "end":  13, "type": "string", "name": "course_id"},
        {"start":  13, "end":  15, "type": "string", "name": "slope"},
        {"start":  15, "end":  17, "type": "string", "name": "wood"},
        {"start":  17, "end":  19, "type": "string", "name": "dirt"},
        {"start":  19, "end":  21, "type": "string", "name": "turf"},
        {"start":  21, "end":  23, "type": "string", "name": "pool"},
        {"start":  23, "end":  25, "type": "string", "name": "hurdle"},
        {"start":  25, "end":  27, "type": "string", "name": "poly"},
        {"start":  27, "end":  28, "type": "string", "name": "training_distance"},
        {"start":  28, "end":  29, "type": "string", "name": "training_point"},
        {"start":  29, "end":  32, "type": "string", "name": "workout_score"},
        {"start":  32, "end":  35, "type": "string", "name": "condition_score"},
        {"start":  35, "end":  36, "type": "string", "name": "training_value"},
        {"start":  36, "end":  37, "type": "string", "name": "condition_score_diff_id"},
        {"start":  37, "end":  77, "type": "string", "name": "training_comment"},
        {"start":  77, "end":  85, "type": "string", "name": "comment_yyyymmdd"},
        {"start":  85, "end":  86, "type": "string", "name": "training_evaluation"},
        {"start":  86, "end":  89, "type": "string", "name": "last_week_workout_score"},
        {"start":  89, "end":  91, "type": "string", "name": "last_week_course_id"},
    ]
}
